@@ -11,6 +11,7 @@ COLOR_NAMES = "/".join([style.name.lower() for style in list(AnsiFGColor)])
 class Header:
     FILEPATH = "filepath"
     TESTFUNC = "function"
+    SUBTOTAL = "SUBTOTAL"
 
 
 class ColorPoicy:
@@ -60,7 +61,7 @@ class Option(Enum):
             """\
             verbosity level for pytest-md-report. if not set, using verbosity level of pytest.
             defaults to 0.
-        """
+            """
         ),
     )
     MD_REPORT_COLOR = (
