@@ -114,6 +114,9 @@ def pytest_addoption(parser):
 
 
 def is_make_md_report(config: Config) -> bool:
+    if config.option.help:
+        return False
+
     make_report = config.option.md_report
 
     if make_report is None:
@@ -302,24 +305,27 @@ def style_filter(cell: Cell, **kwargs: Any) -> Optional[Style]:
     is_skipped = False
 
     headers = writer.headers
-    if headers[cell.col] in (Header.FILEPATH, Header.TESTFUNC):
-        error_count = sum(
-            [
-                writer.value_matrix[cell.row][headers.index("failed")],
-                writer.value_matrix[cell.row][headers.index("error")],
-            ]
-        )
-        skip_count = sum(
-            [
-                writer.value_matrix[cell.row][headers.index("skipped")],
-                writer.value_matrix[cell.row][headers.index("xfailed")],
-                writer.value_matrix[cell.row][headers.index("xpassed")],
-            ]
-        )
+    if headers[cell.col] in (Header.FILEPATH, Header.TESTFUNC, Header.SUBTOTAL):
+        error_ct_list = []
+        if "failed" in headers:
+            error_ct_list.append(writer.value_matrix[cell.row][headers.index("failed")])
+        if "error" in headers:
+            error_ct_list.append(writer.value_matrix[cell.row][headers.index("error")])
 
-        is_failed = error_count > 0
-        is_skipped = skip_count > 0
-        is_passed = error_count == 0 and skip_count == 0
+        skip_ct_list = []
+        if "skipped" in headers:
+            skip_ct_list.append(writer.value_matrix[cell.row][headers.index("skipped")])
+        if "xfailed" in headers:
+            skip_ct_list.append(writer.value_matrix[cell.row][headers.index("xfailed")])
+        if "xpassed" in headers:
+            skip_ct_list.append(writer.value_matrix[cell.row][headers.index("xpassed")])
+
+        error_ct = sum(error_ct_list)
+        skip_ct = sum(skip_ct_list)
+
+        is_failed = error_ct > 0
+        is_skipped = skip_ct > 0
+        is_passed = error_ct == 0 and skip_ct == 0
 
     if is_passed or headers[cell.col] in ("passed"):
         fg_color, bg_color = retriever.retrieve_fg_bg_color(color_map[FGColor.SUCCESS])
@@ -361,6 +367,7 @@ def make_md_report(
     verbosity_level = retrieve_verbosity_level(config)
 
     outcomes = ["passed", "failed", "error", "skipped", "xfailed", "xpassed"]
+    outcomes = [key for key in outcomes if total_stats.get(key, 0) > 0]
     results_per_testfunc = {}  # type: Dict[Tuple, Dict[str, int]]
 
     for stat_key, values in reporter.stats.items():
@@ -387,15 +394,15 @@ def make_md_report(
     writer = TableWriterFactory.create_from_format_name("md")
 
     matrix = [
-        list(key) + [results.get(key, 0) for key in outcomes]  # type: ignore
+        list(key) + [results.get(key, 0) for key in outcomes] + [sum(results.values())]  # type: ignore
         for key, results in results_per_testfunc.items()
     ]
     if verbosity_level == 0:
-        writer.headers = [Header.FILEPATH] + outcomes
-        matrix.append(["TOTAL"] + [total_stats.get(key, 0) for key in outcomes])  # type: ignore
+        writer.headers = [Header.FILEPATH] + outcomes + [Header.SUBTOTAL]
+        matrix.append(["TOTAL"] + [total_stats.get(key, 0) for key in outcomes] + [sum(total_stats.values())])  # type: ignore
     elif verbosity_level >= 1:
-        writer.headers = [Header.FILEPATH, Header.TESTFUNC] + outcomes
-        matrix.append(["TOTAL", ""] + [total_stats.get(key, 0) for key in outcomes])  # type: ignore
+        writer.headers = [Header.FILEPATH, Header.TESTFUNC] + outcomes + [Header.SUBTOTAL]
+        matrix.append(["TOTAL", ""] + [total_stats.get(key, 0) for key in outcomes] + [sum(total_stats.values())])  # type: ignore
 
     writer.margin = retrieve_report_margin(config)
     writer.value_matrix = matrix
